@@ -7,7 +7,6 @@ if ($machine ne "arm") {
 } else {
     $asroot = "fakeroot";
 }
-$machine = "armel";
 
 my $repo = "https://qgvdial.googlecode.com/svn/trunk";
 my $cmd;
@@ -63,11 +62,20 @@ system("mv $basedir/qgv-tp/data/org.freedesktop.Telepathy.ConnectionManager.qgvt
 # Change the name of the desktop file so that it can be directly used in the compilation
 system("mv $basedir/build-files/qgvdial.desktop.maemo $basedir/build-files/qgvdial.desktop");
 
+if ($machine eq "arm") {
+    $cmd="sed 's/\\/targets\\/FREMANTLE_ARMEL//g' $basedir/Makefile >$basedir/Makefile1 ; mv $basedir/Makefile1 $basedir/Makefile ; sed 's/\\/targets\\/FREMANTLE_ARMEL//g' $basedir/qgv-tp/Makefile >$basedir/qgv-tp/Makefile1 ; mv $basedir/qgv-tp/Makefile1 $basedir/qgv-tp/Makefile ; sed 's/\\/targets\\/FREMANTLE_ARMEL//g' $basedir/qgv-util/Makefile >$basedir/qgv-util/Makefile1 ; mv $basedir/qgv-util/Makefile1 $basedir/qgv-util/Makefile";
+    system($cmd);
+}
+
 # Execute the rest of the build command
-$cmd = "cd $basedir && $asroot $mad dpkg-buildpackage && $mad remote -r org.maemo.qgvdial send ../qgvdial_$qver-1_$machine.deb && $mad remote -r org.maemo.qgvdial install qgvdial_$qver-1_$machine.deb";
+$cmd = "cd $basedir && $asroot $mad dpkg-buildpackage -rfakeroot -sa -S";
 system($cmd);
 
-$cmd = "dput -f fremantle-upload qgvdial*.changes";
+if ($machine ne "arm") {
+    $cmd = "dput -f fremantle-upload qgvdial*.changes";
+} else {
+    $cmd = "dput -f fremantle-extras-builder qgvdial*.changes";
+}
 system($cmd);
 
 exit();
